<?php

/*************************************************
## agrikon Current Page URL
*************************************************/
add_filter( 'woocommerce_widget_get_current_page_url', 'agrikon_current_page_url', 10, 2 );
function agrikon_current_page_url( $link, $that ) {
    if ( isset( $_GET['filter_cat'] ) ) {
        $link = add_query_arg( 'filter_cat', wc_clean( wp_unslash( $_GET['filter_cat'] ) ), $link );
    }

    if ( isset( $_GET['shop_view'] ) ) {
        $link = add_query_arg( 'shop_view', wc_clean( wp_unslash( $_GET['shop_view'] ) ), $link );
    }

    return $link;
}


/*************************************************
## Load More Button
*************************************************/
function agrikon_load_more_button(){
    echo '<div class="row row-more agrikon-more mt-30">
    <div class="col-12 nt-pagination -align-center">
    <div class="agrikon-btn thm-btn agrikon-load-more" data-title="'.esc_html__('Loading...','agrikon').'" data-nomore="'.esc_html__('No More Products','agrikon').'">'.esc_html__('Load More','agrikon').'</div>
    </div>
    </div>';
}


/*************************************************
## Infinite Pagination
*************************************************/
function agrikon_infinite_scroll(){
    echo '<div class="row row-infinite agrikon-more mt-30">
    <div class="col-12 nt-pagination -align-center">
    <div class="agrikon-load-more" data-title="'.esc_html__('Loading...','agrikon').'" data-nomore="'.esc_html__('No More Products','agrikon').'">'.esc_html__('Loading...','agrikon').'</div>
    </div>
    </div>';
}


/*************************************************
## Load More CallBack
*************************************************/
add_action( 'wp_ajax_nopriv_load_more', 'agrikon_load_more_callback' );
add_action( 'wp_ajax_load_more', 'agrikon_load_more_callback' );
function agrikon_load_more_callback() {

    $output = '';

    $args = array(
        'post_type' => 'product',
        'posts_per_page' => $_POST['per_page'],
        'paged' => $_POST['current_page'] + 1
    );

    // Price Slider
    if ( $_POST['min_price'] != null || $_POST['max_price'] != null ) {
        $args['meta_query'][] = wc_get_min_max_price_meta_query( array(
          'min_price' => $_POST['min_price'],
          'max_price' => $_POST['max_price']
        ));
    }

    // On Sale Products
    if ( isset( $_POST['on_sale'] ) ) {
        $args['post__in'] = $_POST['on_sale'];
    }

    // Orderby
    $orderby_value = isset( $_POST['orderby'] ) ? wc_clean( (string) wp_unslash( $_POST['orderby'] ) ) : wc_clean( get_query_var( 'orderby' ) );

    if ( ! $orderby_value ) {
        if ( $_POST['is_search'] == 'yes' ) {
            $orderby_value = 'relevance';
        } else {
            $orderby_value = apply_filters( 'woocommerce_default_catalog_orderby', get_option( 'woocommerce_default_catalog_orderby', 'menu_order' ) );
        }
    }

    switch ( $orderby_value ) {
        case 'menu_order':
        $args['orderby'] = 'menu_order title';
        $args['order']   = 'ASC';
        break;
        case 'relevance':
        $args['orderby'] = 'relevance';
        $args['order']   = 'DESC';
        break;
        case 'price':
        add_filter( 'posts_clauses', array( WC()->query, 'order_by_price_asc_post_clauses' ) );
        break;
        case 'price-desc':
        add_filter( 'posts_clauses', array( WC()->query, 'order_by_price_desc_post_clauses' ) );
        break;
        case 'popularity':
        $args['meta_key'] = 'total_sales';
        add_filter( 'posts_clauses', array( WC()->query, 'order_by_popularity_post_clauses' ) );
        break;
        case 'rating':
        $args['meta_key'] = '_wc_average_rating'; // phpcs:ignore WordPress.DB.SlowDBQuery.slow_db_query_meta_key
        $args['order']    = 'DESC';
        $args['orderby']  = 'meta_value_num';
        add_filter( 'posts_clauses', array( WC()->query, 'order_by_rating_post_clauses' ) );
        break;
    }

    // Product Category Filter Widget on shop page
    if ( $_POST['filter_cat'] != null ) {
        if ( !empty( $_POST['filter_cat'] ) ) {
            $args['tax_query'][] = array(
                'taxonomy' => 'product_cat',
                'field'    => 'id',
                'terms'    => explode( ',', $_POST['filter_cat'] )
            );
        }
    }

    // Product Category Page
    if ( $_POST['cat_id'] != null ) {
        $args['tax_query'][] = array(
            'taxonomy' => 'product_cat',
            'field'    => 'id',
            'terms'    => $_POST['cat_id']
        );
    }

    // Product Brands Filter Widget on shop page
    if ( $_POST['filter_brand'] != null ) {
        $args['tax_query'] = array(
            array(
                'taxonomy' => 'agrikon_product_brands',
                'field'    => 'id',
                'terms'    => $_POST['filter_brand']
            )
        );
    }

    // Product Brands Page
    if ( is_tax( 'agrikon_product_brands' ) && $_POST['brand_id'] != null ) {
        $args['tax_query'] = array(
            array(
                'taxonomy' => 'agrikon_product_brands',
                'field'    => 'id',
                'terms'    => $_POST['brand_id']
            )
        );
    }

    // Product Filter By widget
    if ( isset( $_POST['layered_nav'] ) ) {
        $choosen_attributes = $_POST['layered_nav'];

        foreach ( $choosen_attributes as $taxonomy => $data ) {
            $args['tax_query'][] = array(
                'taxonomy'         => $taxonomy,
                'field'            => 'slug',
                'terms'            => $data['terms'],
                'operator'         => 'and' === $data['query_type'] ? 'AND' : 'IN',
                'include_children' => false
            );
        }
    }
    //Loop
    $loop = new WP_Query( $args );
    if ( $loop->have_posts() ) {
        while ( $loop->have_posts() ) : $loop->the_post();
            wc_get_template_part( 'content', 'product' );
        endwhile;
    }
    wp_reset_postdata();

    wp_die();
}
